#!/usr/bin/python3
#v0.2 March 5 2011
import time,subprocess,os,sys,re
import inputfiles
from math import *
#import psyco  # psyco increases speed by 20%
#psyco.full()
from optparse import OptionParser
usage="usage: %prog expname [options]"
parser = OptionParser(usage=usage, version="%prog 0.1")
parser.add_option("-w", dest="wvapfile",type="string",help="file for mixrat",default="")
parser.add_option("--outdir", dest="outdir",type="string",help="directory for output files",default="exp")
parser.add_option("-c", dest="co2vmix",type="float",help="co2 ppmv string",default=3.55e-4)
parser.add_option("--cu", dest="cu",type="float",help="surface sensible flux paramter, Watts/m^2 per degree diff ",default=20.)
parser.add_option("--tinit", dest="tinit",type="float",help="initial temperature for everything",default=250.)
parser.add_option("--dt", dest="dt",type="float",help="timestep in days",default=0.5)
parser.add_option("--nadj", dest="nadj",type="int",help="convective adjustments per time step",default=100)
parser.add_option("--solcnst", dest="solcnst",type="float",help="effective solar const",default=700.)
parser.add_option("--it", dest="itmax",type="int",help="number of iterations",default=1000)
parser.add_option("--tstop", dest="tstop",type="float",help="time to stop before itmax",default=None)
parser.add_option("-m", action="store_true", dest="moist", default=False)

(opt, args) = parser.parse_args()
#print args
#print opt,dir(opt)
try:
    expname=args[0]
except:
    expname='myexp'
crminfile=opt.outdir+'/'+expname+'.in'
crmoutfile=opt.outdir+'/'+expname+'.out'
crmlevfile=opt.outdir+'/'+expname+'.lev'
crmlayfile=opt.outdir+'/'+expname+'.lay'
#####################
itmax=opt.itmax
tstep=opt.dt
nadj=opt.nadj
co2vmix=opt.co2vmix
cu=opt.cu
initialtem=opt.tinit
solcnst=opt.solcnst
moist=opt.moist
keepmixrat=False
if opt.wvapfile:
    keepmixrat=True
if tstep>0.499: #for the standard experiments out to equilibrium
    dta = [.01]*20 + [.02]*40 + [.1]*90 + [tstep]*itmax + [.25*tstep]*itmax
else: #for smaller tstep
    dta = [tstep]*itmax
###################################
layers=18
levels=layers+1
surpres=1013.
grav=9.807
cp=1004.
Rair=287.
Rvap=461.5
bigL=2.5e6
day=86400.
######################
def ripout(thefile,tag,skip,num,pos):
    l=len(tag)
    vals=[]
    lines=thefile.split('\n')
    foundit=False
    for i in range(len(lines)):
        if re.search(tag,lines[i]):
            foundit=True
            break
    if not foundit:
        print("ripout fail, could not find tag: ",tag)
        sys.exit()
    for j in range(num):
        v=lines[i+skip+j].split()
        try:
            vals.append(float(v[pos]))
        except:
            print("ripout fail:",lines[i+skip+j],v,v[pos])
    if num==1:
        return vals[0]
    else:
        return vals
######################
def skelr(skelfile,tag,vals,form):
    i=0
    modfile=[]
    for line in skelfile.split('\n'):
        if re.search(tag,line):
            line=line.replace(tag, form % vals[i])
            i=i+1
        modfile.append(line)
    return "\n".join(modfile)
#####################
def vecadd(a,b,mult=1.):
    result=[]
    for i in range(len(a)):
        result.append(a[i]+mult*b[i])
    return result
#####################
def sat_vap_pres(t):
    return 6.11*exp(5422*(1/273.-1/t))
####################
def mixingratio(t,p):
    mixrat=[0.]*layers
    js=1
    for j in range(layers-1):
        if t[j+1] > t[j]:
            js=j
            break
    js=max(1,js)
#       js=max(1,0) # BUG!!!
    r=list(range(layers))
    r.reverse()
    for j in r:
        if j>=js:
            esat=sat_vap_pres(t[j])
            mixsat=.662*esat/(pres[j]-esat)
            rh=.68*p[j]/surpres
            mixrat[j]=rh*mixsat
        else:
            mixrat[j]=mixrat[js]
    return mixrat
######################
def moistrate(t,pf):
    malr=[0.]*levels
    for j in range(1,layers):
        tavg=.5*(t[j]+t[j-1])
        esat=sat_vap_pres(tavg)
        mixsat=.662*esat/(pf[j]-esat)
        numer=1.+bigL*mixsat/(Rair*tavg)
        denom=1.+bigL**2*mixsat/(Rvap*cp*tavg**2)
        malr[j]=(grav/cp)*(numer/denom)
    malr[1]=malr[2]
    malr[-1]=malr[-2]
    return malr
######################
def p2z(p,T):
    z=[0.]
    zz=0.
    lnp=[log(x) for x in p]
    r=list(range(len(T)))
    r.reverse()
    for j in r:
        dz=Rair*T[j]*(lnp[j+1]-lnp[j])/grav
        zz=zz+dz
        z.append(zz)
    z.reverse()
    return z
########################
def zf2zm(zf):
    zm=[0.]*layers
    for j in range(layers):
        zm[j]=.5*(zf[j+1]+zf[j])
    return zm
########################
def conadj(t,zm,ml,lapse,n):
    texf=[0.]*(len(t)+1)
    r=list(range(len(t)-1))
#       r.reverse()
    for i in range(n):
        for j in r:
            flux=max(0, ( lapse[j+1]*(zm[j+1]-zm[j]) +t[j+1]-t[j] ) /  (1./ml[j+1]+1./ml[j]))
            t[j+1]+=-flux/ml[j+1]
            t[j]+=flux/ml[j]
            texf[j+1]+=flux/(dt*day)
    return texf
############################################
if keepmixrat:
    stan=open(opt.wvapfile,'r')
    standard=stan.read()
    mixrat_standard=ripout(standard,'^    ',0,layers,3)
input=inputfiles.skl_clr
airinit=[initialtem]*layers
skninit=initialtem
skntem=skninit
airtem=airinit[:]
input=skelr(input,'SOLCST',[solcnst],'%6.1f')
input=skelr(input,'CO2VMIX',[co2vmix],'%7.2e')
pres=ripout(input,r'^    ',0,layers,1)
presf=[pres[0]/2.]
for j in range(layers-1):
    presf.append(0.5*(pres[j]+pres[j+1]))
presf.append(surpres)
ml=[]
for j in range(layers):
    ml.append(cp*100.*(presf[j+1]-presf[j])/grav)
extrap=(surpres-pres[-1])/(pres[-1]-pres[-2])
###############################
it=0
time=0.
for dt in dta:
    myinput=skelr(input,'AIRTEM',airtem,'%6.2f')
    if keepmixrat:
        mine=mixrat_standard
    else:
        mine=mixingratio(airtem,pres)
    myinput=skelr(myinput,'MIXINGRAT',mine,'%9.3e')
    myinput=skelr(myinput,'SKNTEM',[skntem],'%6.2f')
    proc=subprocess.Popen("./crm", stdin=subprocess.PIPE,  stdout=subprocess.PIPE)
    proc.stdin.write(myinput.encode())
    ret=proc.communicate()[0].decode()
    hrate=ripout(ret,'Heating rates',3,layers,4)
    swdsfc=ripout(ret,' SW down flux sfc',0,1,5)
    swusfc=ripout(ret,' SW up flux sfc',0,1,5)
    lwdsfc=ripout(ret,' LW down flux sfc',0,1,5)
    lwusfc=ripout(ret,' LW up flux sfc',0,1,5)
    swdtoa=ripout(ret,' SW down flux TOA',0,1,5)
    swutoa=ripout(ret,' SW up flux TOA',0,1,5)
    lwutoa=ripout(ret,' LW up flux TOA',0,1,5)
    suremis=lwusfc/(5.67e-8*skntem**4)
    surair=airtem[-1]+extrap*(airtem[-1]-airtem[-2])
    sensflux=cu*(skntem-surair)
    if cu==0.:
        needstobe=swdsfc-swusfc+lwdsfc-sensflux
        skntem=(needstobe/(suremis*5.67e-8))**.25
    else:
        netup=-swdsfc+swusfc-lwdsfc+sensflux+lwusfc
        dndt=4*suremis*5.67e-8*skntem**3+cu
        skntem+=-netup/dndt
    radforce=swdtoa-swutoa-lwutoa
    airtem=vecadd(airtem,hrate,mult=dt)
    airtem[-1]+=sensflux*dt*day/ml[-1]
    zf=p2z(presf,airtem)
    zm=zf2zm(zf)
    if moist:
        lapse=moistrate(airtem,presf)
    else:
        lapse=[6.5e-3]*levels
    texf=conadj(airtem,zm,ml,lapse,nadj)
    it+=1
    time+=dt
    print(it,dt,time,airtem[0],airtem[10],airtem[-1],surair,skntem,radforce)
    if opt.tstop!=None and time>=opt.tstop: break
zf=p2z(presf,airtem)
zm=zf2zm(zf)
iuf=open(crminfile,'w')
iuf.write(myinput)
ouf=open(crmoutfile,'w')
ouf.write(ret)
layf=open(crmlayfile,'w')
levf=open(crmlevfile,'w')
alapse=[0.]*levels
header="#{solcnst:%7.2f, co2vmix:%9.2e, cu:%7.1f, moist:%d,  wvapfile:%s}" % (solcnst,co2vmix,cu,moist,opt.wvapfile)
header2="#{itmax:%7d, tstep:%7.3f, nadj:%5d} " % (itmax,tstep,nadj)
header3="#{layairt:%9.4f, surairt:%9.4f, skntem:%9.4f, radforce:%9.2e, sensflux:%9.2e } " % (airtem[-1],surair,skntem, radforce, sensflux)
print(header, file=levf)
print(header2, file=levf)
print(header3, file=levf)
print(header, file=layf)
print(header2, file=layf)
print(header3, file=layf)
for j in range(layers-1):
    alapse[j+1]=(airtem[j+1]-airtem[j])/(zm[j]-zm[j+1])
for j in range(layers):
    print(j+1, zf[j],presf[j],lapse[j],alapse[j],texf[j], file=levf)
    print(j+1, zm[j],pres[j],airtem[j],mine[j], file=layf)
j=layers
print(j+1, zf[j],presf[j],lapse[j],alapse[j],texf[j], file=levf)
print("heating rate in lowest layer",(sensflux-texf[-2])*day/ml[-1])
